# RerankResult

Rerank result for ranking.






## Methods

???- note "clear"

    D.clear() -> None.  Remove all items from D.


???- note "copy"

    D.copy() -> a shallow copy of D


???- note "fromkeys"

    Create a new dictionary with keys from iterable and values set to value.

    **Parameters**

    - **iterable**
    - **value**     – defaults to `None`

???- note "get"

    Return the value for key if key is in the dictionary, else default.

    **Parameters**

    - **key**
    - **default**     – defaults to `None`

???- note "items"

    D.items() -> a set-like object providing a view on D's items


???- note "keys"

    D.keys() -> a set-like object providing a view on D's keys


???- note "pop"

    D.pop(k[,d]) -> v, remove specified key and return the corresponding value.

    If the key is not found, return the default if given; otherwise, raise a KeyError.


???- note "popitem"

    Remove and return a (key, value) pair as a 2-tuple.

    Pairs are returned in LIFO (last-in, first-out) order. Raises KeyError if the dict is empty.


???- note "setdefault"

    Insert key with a value of default if key is not in the dictionary.

    Return the value for key if key is in the dictionary, else default.

    **Parameters**

    - **key**
    - **default**     – defaults to `None`

???- note "update"

    D.update([E, ]**F) -> None.  Update D from mapping/iterable E and F. If E is present and has a .keys() method, then does:  for k in E.keys(): D[k] = E[k] If E is present and lacks a .keys() method, then does:  for k, v in E: D[k] = v In either case, this is followed by: for k in F:  D[k] = F[k]


???- note "values"

    D.values() -> an object providing a view on D's values
